]> git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
corrected the misspelled name GAME_NEXIUZ (and related things) to GAME_NEXUIZ (and...
authorhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Fri, 28 Mar 2003 16:45:23 +0000 (16:45 +0000)
committerhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Fri, 28 Mar 2003 16:45:23 +0000 (16:45 +0000)
git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@2875 d7cf8633-e32d-0410-b094-e92efae38249

cl_main.c
cl_particles.c
common.c
common.h
gl_rmain.c

index 6b6a4f79cf631819794d8f5219ee171003ef797a..d3972a6abdafc4c123fdc8801ce59d2e284601bd 100644 (file)
--- a/common.c
+++ b/common.c
@@ -670,8 +670,8 @@ void COM_InitGameType (void)
 
        if (strstr(name, "transfusion"))
                gamemode = GAME_TRANSFUSION;
-       else if (strstr(name, "nexiuz"))
-               gamemode = GAME_NEXIUZ;
+       else if (strstr(name, "nexuiz"))
+               gamemode = GAME_NEXUIZ;
        else if (strstr(name, "nehahra"))
                gamemode = GAME_NEHAHRA;
        else if (strstr(name, "hipnotic"))
@@ -683,8 +683,8 @@ void COM_InitGameType (void)
 
        if (COM_CheckParm ("-transfusion"))
                gamemode = GAME_TRANSFUSION;
-       else if (COM_CheckParm ("-nexiuz"))
-               gamemode = GAME_NEXIUZ;
+       else if (COM_CheckParm ("-nexuiz"))
+               gamemode = GAME_NEXUIZ;
        else if (COM_CheckParm ("-nehahra"))
                gamemode = GAME_NEHAHRA;
        else if (COM_CheckParm ("-hipnotic"))
@@ -712,8 +712,8 @@ void COM_InitGameType (void)
                gamename = "DarkPlaces-Nehahra";
                gamedirname = "nehahra";
                break;
-       case GAME_NEXIUZ:
-               gamename = "Nexiuz";
+       case GAME_NEXUIZ:
+               gamename = "Nexuiz";
                gamedirname = "data";
                break;
        case GAME_TRANSFUSION:
index 7058d0b3be74a9296f96c0b5b607deddb1b4de0f..80e7c17c75feff1d078f177a6b8d9a923138fe02 100644 (file)
--- a/common.h
+++ b/common.h
@@ -166,7 +166,7 @@ extern      struct cvar_s   registered;
 #define GAME_HIPNOTIC 1
 #define GAME_ROGUE 2
 #define GAME_NEHAHRA 3
-#define GAME_NEXIUZ 4
+#define GAME_NEXUIZ 4
 #define GAME_TRANSFUSION 5
 
 extern int gamemode;
index 91fba30b7324dbb41f2708192f07d69570e40925..fc8a8d1fb8b9e795c240ec5ab1cd36f935f7d23a 100644 (file)
@@ -230,7 +230,7 @@ void GL_Main_Init(void)
        Cvar_RegisterVariable (&r_fullbright);
        Cvar_RegisterVariable (&r_textureunits);
        Cvar_RegisterVariable (&r_shadow_cull);
-       if (gamemode == GAME_NEHAHRA || gamemode == GAME_NEXIUZ)
+       if (gamemode == GAME_NEHAHRA || gamemode == GAME_NEXUIZ)
                Cvar_SetValue("r_fullbrights", 0);
        R_RegisterModule("GL_Main", gl_main_start, gl_main_shutdown, gl_main_newmap);
 }
--- a/cl_main.c
+++ b/cl_main.c
@@ -625,7 +625,7 @@ static void CL_RelinkNetworkEntities(void)
                {
                        if (effects & EF_BRIGHTFIELD)
                        {
-                               if (gamemode == GAME_NEXIUZ)
+                               if (gamemode == GAME_NEXUIZ)
                                {
                                        dlightcolor[0] += 100.0f;
                                        dlightcolor[1] += 200.0f;
index 2dbe39dc99ff463ffc1b68e4e748921b61d8633b..e778e9ee644081cdb2f6a4baaa32572b660b324b 100644 (file)
@@ -1075,7 +1075,7 @@ void CL_RocketTrail (vec3_t start, vec3_t end, int type, entity_t *ent)
                                        particle(pt_static, PARTICLE_BILLBOARD, 0x303030, 0x606060, tex_smoke[rand()&7], true, PBLEND_ALPHA, dec, dec, 64, 320, 9999, 0, 0, pos[0], pos[1], pos[2], lhrandom(-4, 4), lhrandom(-4, 4), lhrandom(0, 16), 0, 0, 0, 0, 0, 0);
                                }
                                break;
-                       case 8: // Nexiuz plasma trail
+                       case 8: // Nexuiz plasma trail
                                dec = 4;
                                if (smoke)
                                {
index 6363ad1e2fa39998754c67ad5d00a557d7c4fcb9..4d9c9d556f8bc4f11eaa976eb6e2e9010e562bc2 100644 (file)